VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "CTileGroupList"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
Option Explicit

Private lngNumTileGroups As Long
Private lngNumTileGroupsM1 As Long     ' Field is numTileGroups-1 (Why? We don't know)

Private TileGroup() As CTileGroup

Private lngMaxWidth As Long
Private lngMaxHeight As Long


Public Function OpenFile(strFileName As String) As Long
    Dim lngFileNum As Long

    ' Check if the file exists
    If Len(Dir(strFileName)) = 0 Then
        ' Error, file doesn't exist
        OpenFile = -1
        Exit Function
    End If

    ' Open the file
    lngFileNum = FreeFile
    Open strFileName For Binary As #lngFileNum

    ' Check file size
    If LOF(lngFileNum) <= 0 Then
        ' Error, file is empty
        Close #lngFileNum
        OpenFile = -1
        Exit Function
    End If

    ' Read the file data
    OpenFile = ReadTileGroupData(lngFileNum)

    ' Close the file
    Close #lngFileNum
End Function

Public Function SaveFile(strFileName As String) As Long
    Dim lngFileNum As Long

    ' Open the file
    lngFileNum = FreeFile
    Open strFileName For Binary As #lngFileNum

    ' Write the file data
    SaveFile = WriteTileGroupData(lngFileNum)

    ' Close the file
    Close #lngFileNum
End Function

Public Function ReadTileGroupData(lngFileNum As Long) As Long
    Dim i As Long
    Dim stringLength As Long

    ' Read the header
    Get #lngFileNum, , lngNumTileGroups
    Get #lngFileNum, , lngNumTileGroupsM1       ' Note: This field is probably named wrong (no relation to previous?)

    ' Allocate space to hold all the tile groups
    ReDim TileGroup(NumTileGroups - 1) As CTileGroup

    ' Read all the tile groups
    For i = 0 To lngNumTileGroups - 1
        ' Create a new tile group object
        Set TileGroup(i) = New CTileGroup
        With TileGroup(i)
            .ReadTileGroup lngFileNum

            ' Update max of width and height
            If .Width > lngMaxWidth Then lngMaxWidth = .Width
            If .Height > lngMaxHeight Then lngMaxHeight = .Height
        End With
    Next i

    ' Return success
    ReadTileGroupData = 0
End Function

Public Function WriteTileGroupData(lngFileNum As Long) As Long
    Dim i As Long

    ' Write the header
    Put #lngFileNum, , lngNumTileGroups
    Put #lngFileNum, , lngNumTileGroupsM1
    
    ' Write all the tile groups
    For i = 0 To lngNumTileGroupsM1     ' Might as well make use of it! :p
        TileGroup(i).WriteTileGroup lngFileNum
    Next i
    
    ' Return success
    WriteTileGroupData = 0
End Function


Public Property Get NumTileGroups() As Long
    NumTileGroups = lngNumTileGroups
End Property

Public Property Get MaxWidth() As Long
    MaxWidth = lngMaxWidth
End Property

Public Property Get MaxHeight() As Long
    MaxHeight = lngMaxHeight
End Property

Public Property Get Group(index As Long) As CTileGroup
    ' Error check the index
    If index < 0 Or index >= lngNumTileGroups Then
        ' Invalid index. Return Null.
        Exit Property
    End If

    ' Return the tile group
    Set Group = TileGroup(index)
End Property


Public Sub AddGroup(newTileGroup As CTileGroup)
    ' Increase array size
    lngNumTileGroups = lngNumTileGroups + 1
    lngNumTileGroupsM1 = lngNumTileGroups - 1
    ' Allocate more space
    ReDim Preserve TileGroup(lngNumTileGroupsM1)

    ' Set the new element
    Set TileGroup(lngNumTileGroupsM1) = newTileGroup
End Sub

Public Function RemoveGroup(groupIndex As Long) As CTileGroup
    Dim i As Long

    ' Error check the index
    If groupIndex < 0 Or groupIndex >= lngNumTileGroups Then
        ' There is no group to remove
        Exit Function
    End If

    ' Return the group being removed
    Set RemoveGroup = TileGroup(groupIndex)

    ' Shift array back
    For i = groupIndex To lngNumTileGroups - 2
        ' Copy the tile group back one space
        Set TileGroup(i) = TileGroup(i + 1)
    Next i

    ' Decrease the array size
    lngNumTileGroups = lngNumTileGroups - 1
    lngNumTileGroupsM1 = lngNumTileGroups - 1
    ' Check if we can shrink the array
    If lngNumTileGroupsM1 <> -1 Then
        ' Deallocate unused memory
        ReDim Preserve TileGroup(lngNumTileGroupsM1)
    End If
End Function
