VERSION 5.00
Begin VB.Form frmTileSetOrganizer 
   Caption         =   "Tile Set Organizer"
   ClientHeight    =   9435
   ClientLeft      =   60
   ClientTop       =   450
   ClientWidth     =   18030
   LinkTopic       =   "Form1"
   ScaleHeight     =   629
   ScaleMode       =   3  'Pixel
   ScaleWidth      =   1202
   StartUpPosition =   3  'Windows Default
   Begin VB.PictureBox picTileGroup 
      Height          =   5175
      Left            =   11265
      ScaleHeight     =   341
      ScaleMode       =   3  'Pixel
      ScaleWidth      =   445
      TabIndex        =   3
      Top             =   360
      Width           =   6735
   End
   Begin VB.ComboBox cmbTileGroup 
      Height          =   315
      Left            =   11265
      Style           =   2  'Dropdown List
      TabIndex        =   2
      Top             =   0
      Width           =   6735
   End
   Begin VB.PictureBox picTileSet 
      Height          =   9015
      Left            =   0
      ScaleHeight     =   597
      ScaleMode       =   3  'Pixel
      ScaleWidth      =   745
      TabIndex        =   1
      Top             =   360
      Width           =   11235
   End
   Begin VB.ComboBox cmbTileSet 
      Height          =   315
      Left            =   0
      Style           =   2  'Dropdown List
      TabIndex        =   0
      Top             =   0
      Width           =   11235
   End
End
Attribute VB_Name = "frmTileSetOrganizer"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
Option Explicit

' Default path
Private Const strPath As String = "\Sierra\Outpost2\Maps\"

' Tile set info
Private Const numTileSetsToLoad As Long = 13
Private tileSetCol As New CTileSetList

' Tile group info
Private tileGroups As New CTileGroupList


Private Sub cmbTileGroup_Click()
    ' Redraw the tile group
    picTileGroup_Paint
End Sub

Private Sub cmbTileSet_Click()
    ' Redraw the tile set view
    picTileSet_Paint
End Sub

Private Sub Form_Load()
    Dim i As Long
    Dim lngRetVal As Long
    Dim strFileName As String

    ' Load the tile sets
    lngRetVal = tileSetCol.LoadTileSets(strPath, numTileSetsToLoad)
    ' Check for errors
    If lngRetVal <> numTileSetsToLoad Then
        MsgBox "Error loading tile set well" + Format$(lngRetVal + 1, "0000") + ".bmp", , "Aborting Tile Set Load"
    End If

    ' Add the tile sets to the combo box
    For i = 0 To lngRetVal - 1
        cmbTileSet.AddItem "Well" + Format$(i, "0000")
    Next i

    ' Load the tile group info
    lngRetVal = tileGroups.OpenFile(strPath + "TileGroupInfo")
    ' Check for errors
    If lngRetVal <> 0 Then
        MsgBox "Error loading tile group info", , "Error"
    End If

    ' Add the tile groups to the combo box
    For i = 0 To tileGroups.NumTileGroups - 1
        ' Add the tile group to the combo box
        cmbTileGroup.AddItem "<" + Format$(i) + "> " + tileGroups.Group(i).Name
    Next i

    ' Set the first tile set to be displayed
    cmbTileSet.ListIndex = 0
    ' Set the first tile group to be displayed
    cmbTileGroup.ListIndex = 0
    
    ' **DEBUG
    SortTileGroups
End Sub

Private Sub Form_Resize()
    Dim newViewWidth As Long
    Dim newViewHeight As Long

    ' Resize the tile group view
    picTileGroup.Move Me.ScaleWidth - tileGroups.MaxWidth * 33 - 7, picTileGroup.Top, tileGroups.MaxWidth * 33 + 5, tileGroups.MaxHeight * 33 + 5
    cmbTileGroup.Move picTileGroup.Left, cmbTileGroup.Top, picTileGroup.Width

    ' Resize the tile set view
    newViewWidth = ((picTileGroup.Left - picTileSet.Left - 5) \ 33) * 33 + 5
    newViewHeight = ((Me.ScaleHeight - picTileSet.Top - 5) \ 33) * 33 + 5
    picTileSet.Move picTileSet.Left, picTileSet.Top, newViewWidth, newViewHeight
    ' Resize the combo box
    cmbTileSet.Width = picTileSet.Width

    ' Update the view
    picTileSet_Paint
    picTileGroup_Paint
End Sub

Private Sub picTileGroup_Paint()
    Dim i As Long, j As Long
    Dim tileIndex As Long, groupIndex As Long
    Dim tileSetIndex As Long
    Dim retVal As Long
    Dim currentTileSet As CTileSet

    ' Get the selected tile group
    groupIndex = cmbTileGroup.ListIndex
    ' Get the default tile set to use to draw this tile group
    tileSetIndex = tileSetCol.TileSetIndexOfTile(tileGroups.Group(groupIndex).Tile(0, 0))
    Set currentTileSet = tileSetCol.TileSet(tileSetIndex)

    ' Display the tile group
    For j = 0 To (picTileGroup.ScaleHeight - 1) \ 33
        For i = 0 To (picTileGroup.ScaleWidth - 1) \ 33
            ' Get the tile index
            tileIndex = tileGroups.Group(groupIndex).Tile(i, j)
            ' Map the tile index into a tile set index and a tile index (within that tile set)
            tileSetIndex = tileSetCol.TileSetIndexOfTile(tileIndex)
            Set currentTileSet = tileSetCol.TileSet(tileSetIndex)
            ' Adjust the index into the correct tile group
            tileIndex = tileIndex - tileSetCol.NumTilesUpTo(tileSetIndex)
            ' Display the tile
             retVal = currentTileSet.Paste(picTileGroup.hDC, i * 33 + 1, j * 33 + 1, tileIndex)
            ' Check if the tile failed to draw
            If retVal = 0 Then
                ' Draw the default background color over the tile
                picTileGroup.Line (i * 33 + 1, j * 33 + 1)-(i * 33 + 33, j * 33 + 32), RGB(239, 235, 222), BF
            End If

            ' Draw the border around the tile
            picTileGroup.Line (i * 33, j * 33)-(i * 33 + 33, j * 33 + 33), RGB(0, 0, 0), B
        Next i
    Next j
End Sub

Private Sub picTileSet_Paint()
    Dim i As Long, j As Long
    Dim currentTileIndex As Long
    Dim retVal As Long
    Dim currentTileSet As CTileSet

    ' Cache which tile set to draw
    Set currentTileSet = tileSetCol.TileSet(cmbTileSet.ListIndex)

    ' Draw current tiles
    For j = 0 To (picTileSet.ScaleHeight - 1) \ 33
        For i = 0 To (picTileSet.ScaleWidth - 1) \ 33
            ' Draw the tile
            retVal = currentTileSet.Paste(picTileSet.hDC, i * 33 + 1, j * 33 + 1, currentTileIndex)
            ' Check if the tile failed to draw
            If retVal = 0 Then
                ' Draw the default background color over the tile
                picTileSet.Line (i * 33 + 1, j * 33 + 1)-(i * 33 + 33, j * 33 + 32), RGB(239, 235, 222), BF
            End If

            ' Draw the border around the tile
            If 0 Then       ' **TODO**
                picTileSet.Line (i * 33, j * 33)-(i * 33 + 33, j * 33 + 33), RGB(255, 0, 0), B
            Else
                picTileSet.Line (i * 33, j * 33)-(i * 33 + 33, j * 33 + 33), RGB(0, 0, 0), B
            End If
            ' Update which tile to draw next
            currentTileIndex = currentTileIndex + 1
        Next i
    Next j
End Sub


' **DEBUG**
Private Sub SortTileGroups()
    Dim i As Long
    Dim TileGroup As CTileGroup
    Dim strName As String

    ' Process all tile groups
    For i = 0 To tileGroups.NumTileGroups - 1
        ' Remove the tile group
        Set TileGroup = tileGroups.Group(i)

        ' Get the name so we can decide what to do with it
        strName = TileGroup.Name

        ' Check if it is a sand tile group
        If Left$(strName, 3) = "san" Then
            ' Adjust the tile group name
            TileGroup.Name = Right$(strName, Len(strName) - 3)
            ' Add to sand group collection
            'Debug.Print "<sand>" + tileGroup.Name
        End If
    Next i
End Sub
